@@ -21,13 +21,19 @@
  */
 /*
 	$Log: IOFWQEventSource.cpp,v $
+	Revision 1.3  2002/10/18 23:29:42  collin
+	fix includes, fix cast which fails on new compiler
+	
 	Revision 1.2  2002/09/25 00:27:20  niels
 	flip your world upside-down
 	
 */
 
+// public
+#import <IOKit/firewire/IOFireWireController.h>
+
+// private
 #import "IOFWQEventSource.h"
-#import "IOFireWireController.h"
 
 // IOFWQEventSource
 OSDefineMetaClassAndStructors(IOFWQEventSource, IOEventSource)
