@@ -28,8 +28,11 @@
  *
  */
 
-#import "IOFireWireLib.h"
-#import "IOFireWireLibIsoch.h"
+// public
+#import <IOKit/firewire/IOFireWireLib.h>
+#import <IOKit/firewire/IOFireWireLibIsoch.h>
+
+// private
 #import "IOFireWireLibPriv.h"
 
 namespace IOFireWireLib {
@@ -78,8 +81,6 @@ namespace IOFireWireLib {
 		public:
 									IsochPort( IUnknownVTbl* interface, Device& userclient, bool talking, bool allocateKernPort ) ;
 			virtual					~IsochPort() ;
-//			virtual IOReturn		Init(
-//											Boolean				inTalking) ;
 			
 			// --- methods from kernel isoch port ----------
 			virtual IOReturn		GetSupported(
